==> GraphLab-Create-0.3.0.tar.gz: GraphLab-Create-0.3.0/graphlab/toolkits/model.py <==
"""@package graphlab.toolkits

Defines a basic interface for a model object.
"""
import graphlab.connect as _mt
from graphlab.util import make_internal_url
import graphlab.connect.main as glconnect


def load_model(location):
    """
    Load a model. Assumes the model was previously saved in GraphLab format,
    with Model.save().

    Parameters
    ----------
    location : string    
        Location of the model to load. Can be a local path or a remote URL.
        Because models are saved as directories, there is no file extension.
    """
    _mt._get_metric_tracker().track('toolkit.model.load_model')

    return glconnect.get_unity().load_model(make_internal_url(location))


class Model(object):
    """
    This class defines the minimal interface of a model object
    storing the results from a toolkit function.

    User can query the model object via the `get` function, and
    the list of the queriable fields can be obtained via `list_fields`.

    Model object also supports dictionary type access, e.g. m['pagerank']
    is equivalent to m.get('pagerank'), and m.keys() is equivalent to
    m.list_fields().
    """

    """The UnityModel Proxy Object"""
    __proxy__ = None

    def name(self):
        """
        Returns the name of the model. 

        Returns
        -------
        out : string
            The name of the model object.
        """
        return self.__class__.__name__

    def list_fields(self):
        """
        Get the value of a given field. The list of all fields that can be
        queried can be obtained using the ``list_fields`` method.

        Returns
        -------
        out : list
            The current value of the requested field.
        """
        raise NotImplementedError

    def get(self, field):
        """Return the value for the queried field. 
        
        Each of these fields can be queried in one of two ways:
        
        >>> out = m['field']      
        >>> out = m.get('field')  # equivalent to previous line
        
        Parameters
        ----------
        field : string
            Name of the field to be retrieved.

        Returns
        -------
        out : value
            The current value of the requested field.

        """
        raise NotImplementedError

    def summary(self):
        """Print a summary of the model including a description of training
        data, options, hyper-parameters, and statistics measured during model
        creation."""
        raise NotImplementedError

    def __getitem__(self, key):
        if key in self.list_fields():
            return self.get(key)
        else:
            raise KeyError('Key %s not in model' % key)

    def keys(self):
        return self.list_fields()

    def _get_wrapper(self):
        """Return a lambda function: UnityModel -> M, for constructing model
        class M from a UnityModel proxy."""
        raise NotImplementedError

    def save(self, location):
        """
        Save the model. The model is saved as a directory which can then be
        loaded using the ``load_model`` method.

        Parameters
        ----------
        location : string
            Target destination for the model. Can be a local path or remote URL.
        """
        _mt._get_metric_tracker().track('toolkit.model.save')
        return glconnect.get_unity().save_model(self, make_internal_url(location))

    def __repr__(self):
        ret = "Class: " + self.name() + "\n"
        ret += "Summary:\n"
        summary = self.summary()
        for k in summary:
            ret += "\t %s: %s\n" % (k, summary[k])
        ret += "Available fields for get():\n\t" + str(self.list_fields()) + "\n"
        ret += "\n"
        return ret

==> GraphLab-Create-0.9.0.tar.gz: GraphLab-Create-0.9.0/graphlab/toolkits/model.py <==
"""@package graphlab.toolkits

Defines a basic interface for a model object.
"""
import graphlab.connect as _mt
from graphlab.util import make_internal_url
import graphlab.connect.main as glconnect


def load_model(location):
    """
    Load a model. Assumes the model was previously saved in GraphLab format,
    with Model.save().

    Parameters
    ----------
    location : string
        Location of the model to load. Can be a local path or a remote URL.
        Because models are saved as directories, there is no file extension.
    """
    _mt._get_metric_tracker().track('toolkit.model.load_model')

    return glconnect.get_unity().load_model(make_internal_url(location))


class Model(object):
    """
    This class defines the minimal interface of a model object
    storing the results from a toolkit function.

    User can query the model object via the `get` function, and
    the list of the queriable fields can be obtained via `list_fields`.

    Model object also supports dictionary type access, e.g. m['pagerank']
    is equivalent to m.get('pagerank'), and m.keys() is equivalent to
    m.list_fields().
    """

    """The UnityModel Proxy Object"""
    __proxy__ = None

    def name(self):
        """
        Returns the name of the model.

        Returns
        -------
        out : string
            The name of the model object.
        """
        return self.__class__.__name__

    def list_fields(self):
        """
        Return the a list of queriable key of the model

        Returns
        -------
        out : list[str]
            available fields in the model
        """
        _mt._get_metric_tracker(self.___class__.__module__ + '.list_fields')
        return self.__proxy__.list_fields()

    def get(self, field):
        """Return the value for the queried field.

        Each of these fields can be queried in one of two ways:

        >>> out = m['field']
        >>> out = m.get('field')  # equivalent to previous line

        Parameters
        ----------
        field : string
            Name of the field to be retrieved.

        Returns
        -------
        out : value
            The current value of the requested field.

        """
        if field in self.list_fields():
            return self.__proxy__.get(field)
        else:
            raise KeyError('Key \"%s\" not in model. Available keys are %s.' % (field, ', '.join(self.keys())))

    def summary(self):
        """Print a summary of the model including a description of training
        data, options, hyper-parameters, and statistics measured during model
        creation."""
        raise NotImplementedError

    def __getitem__(self, key):
        return self.get(key)

    def keys(self):
        return self.list_fields()

    def _get_wrapper(self):
        """Return a lambda function: UnityModel -> M, for constructing model
        class M from a UnityModel proxy."""
        raise NotImplementedError

    def save(self, location):
        """
        Save the model. The model is saved as a directory which can then be
        loaded using the ``load_model`` method.

        Parameters
        ----------
        location : string
            Target destination for the model. Can be a local path or remote URL.
        """
        _mt._get_metric_tracker().track('toolkit.model.save')
        return glconnect.get_unity().save_model(self, make_internal_url(location))

    def __repr__(self):
        ret = "Class: " + self.name() + "\n"
        ret += "Summary:\n"
        summary = self.summary()
        for k in summary:
            ret += "\t %s: %s\n" % (k, summary[k])
        ret += "Available fields for get():\n\t" + str(self.list_fields()) + "\n"
        ret += "\n"
        return ret
